summaryrefslogtreecommitdiffstats
path: root/src/core/hle/kernel/k_process.h
diff options
context:
space:
mode:
Diffstat (limited to '')
-rw-r--r--src/core/hle/kernel/k_process.h5
1 files changed, 2 insertions, 3 deletions
diff --git a/src/core/hle/kernel/k_process.h b/src/core/hle/kernel/k_process.h
index 1a53e2be7..8a8c1fcbb 100644
--- a/src/core/hle/kernel/k_process.h
+++ b/src/core/hle/kernel/k_process.h
@@ -8,7 +8,6 @@
#include <cstddef>
#include <list>
#include <string>
-#include <unordered_map>
#include <vector>
#include "common/common_types.h"
#include "core/hle/kernel/k_address_arbiter.h"
@@ -155,8 +154,8 @@ public:
return process_id;
}
- /// Gets the title ID corresponding to this process.
- u64 GetTitleID() const {
+ /// Gets the program ID corresponding to this process.
+ u64 GetProgramID() const {
return program_id;
}